#ifndef DICTBROWSER_H
#define DICTBROWSER_H

#include <KTextBrowser>

class DictBrowser : public QTextBrowser
{
	Q_OBJECT

	friend class DictSearch;
	struct HistoryEntry {
		QString title, page;
		int hpos, vpos;
	};

public:
	DictBrowser(QWidget *parent = 0);
	QStringList backwardList(int len = 10) const
		{ return historyList(backwardHistory, len); };
	QStringList forwardList(int len = 10) const
		{ return historyList(forwardHistory, len); };
	int historySize() const { return histSize; };
	void setHistorySize(int size) { histSize = size; };

public Q_SLOTS:
	void backward() { moveTo(-1); };
	void forward() { moveTo(1); };
	void moveTo(int steps);
	void setPage(const QString &query, const QString &text);
	void appendPage(const QString &query, const QString &text);
	void plainText(bool toggle);
	void setStyleSheet(const QString &style);
	void clearHistory();
	void setFont(const QFont &font);
	void busyCursor(bool busy);
	void pointCursor(const QString &text);
	void focusOutEvent(QFocusEvent *event);

Q_SIGNALS:
	void historyChanged(const QString &);

private:
	QList<HistoryEntry> backwardHistory, forwardHistory;
	HistoryEntry entry;
	QStringList historyList(const QList<HistoryEntry> &history, int len) const;
	int histSize;
	void savePosition();
	void restorePosition();

	QCursor cursor;
	bool plaintext;
	void clearSelection();
	void displayPage(const QString &text);
};

#endif
