#ifndef DICTWIDGETS_H
#define DICTWIDGETS_H

#include "dict.h"

#include <KSelectAction>

class KComboBox;

class DictSelect : public KSelectAction
{
	Q_OBJECT

public:
	DictSelect(QObject *parent = 0);
	QString currentData() const;
	void addData(const QString &text, const QString &data);
	void setList(const DictList &list, const QString &selected);
	void clear();

public Q_SLOTS:
	void setCurrentData(const QString &data);

private Q_SLOTS:
	void actionTriggered(QAction *action);

private:
	KComboBox *combobox;
	QWidget *createWidget(QWidget *parent);
};


#include <KActionMenu>
#include <KMenu>

class DictMenu : public KActionMenu
{
	Q_OBJECT

public:
	DictMenu(QObject *parent = 0);
	QStringList currentData();
	void addData(const QString &text, const QString &data);
	void setList(const DictList &list, const QStringList &selected);
	QString text(const QString &data);
	void clear() { menu()->clear(); };

public Q_SLOTS:
	void setCurrentData(const QStringList &data);

Q_SIGNALS:
	void selected(const QStringList &);

private Q_SLOTS:
	void actionTriggered(QAction *action);
};


#include "dictbrowser.h"

class DictHistory : public QMenu
{
	Q_OBJECT

public:
	enum Direction { Backward, Forward };
	DictHistory(DictBrowser *parent, Direction direction);

Q_SIGNALS:
	void selected(int);

private Q_SLOTS:
	void setList(const QStringList &list);
	void steps(QAction *action);
	void setMenu();

private:
	Direction direction;
	DictBrowser *browser;
};


#include <QListWidget>

class DictView : public QListWidget
{
	Q_OBJECT
public:
	DictView(QWidget *parent = 0);
	void setList(const DictList &list, const QStringList &selected);

Q_SIGNALS:
	void selected(const QStringList&);

public Q_SLOTS:
	void setCurrentData(const QStringList &list);

private Q_SLOTS:
	void selection();

private:
	QString data(int index);
};


#include "ui_searchbar.h"
#include <QWidget>

class DictSearch : public QWidget, public Ui::Searchbar
{
	Q_OBJECT

public:
	DictSearch(DictBrowser *parent);

public Q_SLOTS:
	void findNext() { find(); };
	void findPrev() { find(QTextDocument::FindBackward); };

	void show();
	void hide();
	void clear();

private Q_SLOTS:
	void find(QTextDocument::FindFlags direction = 0);
	void search(const QString &text);

private:
	DictBrowser *browser;
	bool found;

	void keyPressEvent(QKeyEvent *event);
};


#include <KIconLoader>

class DictStatus : public QWidget
{
	Q_OBJECT

public:
	DictStatus(QWidget *parent);

public Q_SLOTS:
	void setStatus(const char *icon, const QString &text, bool enabled);

private:
	QLabel *picture, *label;
};

#endif
