#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include "dict.h"
#include "dictpage.h"
#include "dictsettings.h"
#include "dictwidgets.h"

#include <KXmlGuiWindow>
#include <QClipboard>

class QSplitter;
class QStackedWidget;
class QComboBox;
class QLabel;
class KSelectAction;
class DictBrowser;

class DictWindow : public KXmlGuiWindow
{
	Q_OBJECT

public:
	DictWindow(QWidget *parent = 0);
	~DictWindow();

public Q_SLOTS:
	void define(const QString &query);
	void match(const QString &query);
	void define();
	void match();
	void define(const QUrl &link);
	void setDatabaseMenu(const DictList &list);
	void setStrategyMenu(const DictList &list);
	void setHost(const QString &);

	void configure();
	void authenticate();
	void about(const QString &query);
	void info(QAction *action);
	void response(const QString &text);
	void response(const DictResponse &response);
	void error(const QString &text);
	void cancel();

	void newWindow() { new DictWindow(); };
	void save() {};
	void print() {};

Q_SIGNALS:
	void loading(bool);

private:
	static const int maxQueryLen = 120;
	QComboBox *entry;
	DictBrowser *browser, *matchList;
	DictHistory *backwardMenu, *forwardMenu;
	QMenu *infoMenu;
	KSelectAction *hostMenu;
	DictSelect *strategyMenu;
	DictMenu *databaseMenu;
	DictView *databaseList;
	Dict *dict;

	KSharedConfigPtr config;
	DictSettings *settings;
	QString query;
	DictSearch *search;
	QSplitter *splitter;
	QStackedWidget *sidebar;
	KAction *stop;
	DictStatus *hostStatus, *userStatus;
	DictConf conf;
	DictPage page;

	struct DictTracker {
		bool init, match, correct, extra;
		int hits, misses;
		void clear() { hits = misses = 0;
		match = correct = extra = false; };
		int count() { return hits + misses; };
	} tracker;

	void setupActions();
	void setupBrowser();
	void setupDict();
	void setupStatusbar();
	void url(const QString &query);

	void initDatabases();
	int dbcount() { return databases().size(); };
	QStringList database() { return databaseMenu->currentData(); };
	QString strategy() { return strategyMenu->currentData(); };
	QStringList databases() { return (!database().isEmpty()) ? database() : QStringList(Dict::DefaultDatabase); };
	QString strategies() { return (!strategy().isEmpty() && !tracker.correct) ? strategy() : Dict::DefaultStrategy; };

private Q_SLOTS:
	void readConfig();
	void writeConfig();
	QStringList databaseConfig();
	QString strategyConfig();
	void hostConfig(const QString &host);
	void writeHostConfig();
	void readServerConfig();
	void writeServerConfig();
	void readWidthsConfig();
	void writeWidthsConfig();

	void loadSettings();
	void setHostStatus(bool connected);
	void setUserStatus(bool authenticated);

	void statusMessage(const QString &message);
	void toggleMenubar();
	void setSidebar(int side);
	void setSidebar(QWidget *widget);
	void toggleDatabaseList();
	void toggleMatchList();
	void enableMatchList(bool enable);
	void nextFrame();
	void yankMode(bool toggle);
	void yankClipboard(QClipboard::Mode);
};

#endif
